Index: base/trace_event/memory_allocator_dump_unittest.cc |
diff --git a/base/trace_event/memory_allocator_dump_unittest.cc b/base/trace_event/memory_allocator_dump_unittest.cc |
index 7cd8f516f2c10f3ffa4ac1637cebe5982da375ac..d727ceb7abe226adb4ead51a3156c64c8533d386 100644 |
--- a/base/trace_event/memory_allocator_dump_unittest.cc |
+++ b/base/trace_event/memory_allocator_dump_unittest.cc |
@@ -182,8 +182,9 @@ TEST(MemoryAllocatorDumpTest, GetSize) { |
EXPECT_EQ(1u, dump->GetSize()); |
} |
-// DEATH tests are not supported in Android / iOS. |
-#if !defined(NDEBUG) && !defined(OS_ANDROID) && !defined(OS_IOS) |
+// DEATH tests are not supported in Android/iOS/Fuchsia. |
+#if !defined(NDEBUG) && !defined(OS_ANDROID) && !defined(OS_IOS) && \ |
+ !defined(OS_FUCHSIA) |
TEST(MemoryAllocatorDumpTest, ForbidDuplicatesDeathTest) { |
FakeMemoryAllocatorDumpProvider fmadp; |
MemoryDumpArgs dump_args = {MemoryDumpLevelOfDetail::DETAILED}; |